Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: ext/common.js

Issue 29557738: Issue 5773 - Polyfill iterator for CSSRuleList and StyleSheetList (Closed) Base URL: https://hg.adblockplus.org/adblockpluschrome/
Patch Set: Created Sept. 27, 2017, 10:58 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ext/common.js
===================================================================
--- a/ext/common.js
+++ b/ext/common.js
@@ -46,24 +46,28 @@
for (let listener of this._listeners)
results.push(listener(...args));
return results;
}
};
// Workaround since HTMLCollection and NodeList didn't have iterator support
// before Chrome 51.
// https://bugs.chromium.org/p/chromium/issues/detail?id=401699
let arrayIterator = Array.prototype[Symbol.iterator];
if (!(Symbol.iterator in HTMLCollection.prototype))
HTMLCollection.prototype[Symbol.iterator] = arrayIterator;
if (!(Symbol.iterator in NodeList.prototype))
NodeList.prototype[Symbol.iterator] = arrayIterator;
+ if (!(Symbol.iterator in StyleSheetList.prototype))
+ StyleSheetList.prototype[Symbol.iterator] = arrayIterator;
+ if (!(Symbol.iterator in CSSRuleList.prototype))
+ CSSRuleList.prototype[Symbol.iterator] = arrayIterator;
/* Message passing */
ext.onMessage = new ext._EventTarget();
/* Background page */
@@ -46,24 +46,28 @@
}
};
- // Workaround since HTMLCollection and NodeList didn't have iterator support
- // before Chrome 51.
+ // Workaround since HTMLCollection, NodeList, StyleSheet and
+ // CSSRuleList didn't have iterator support before Chrome 51.
// https://bugs.chromium.org/p/chromium/issues/detail?id=401699
let arrayIterator = Array.prototype[Symbol.iterator];
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld